==> joounit-0.9.5.jar: joo/classes/flexunit/textui/TestRunner.js <==
joo.classLoader.prepare(/*
   Copyright (c) 2008. Adobe Systems Incorporated.
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:

     * Redistributions of source code must retain the above copyright notice,
       this list of conditions and the following disclaimer.
     * Redistributions in binary form must reproduce the above copyright notice,
       this list of conditions and the following disclaimer in the documentation
       and/or other materials provided with the distribution.
     * Neither the name of Adobe Systems Incorporated nor the names of its
       contributors may be used to endorse or promote products derived from this
       software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
*/

"package flexunit.textui",/*
{

   import flash.utils.*;
   import flash.utils.getTimer;
   import flexunit.framework.*;
   import flexunit.runner.BaseTestRunner;*/

   "public class TestRunner extends flexunit.runner.BaseTestRunner",2,function($$private){;return[
   
       "public function TestRunner",function TestRunner$(onComplete/*:Function=null*/, printer/*:Printer=null*/)
       {flexunit.runner.BaseTestRunner.call(this);if(arguments.length<2){if(arguments.length<1){onComplete=null;}printer=null;}
           if(printer == null)
            this.printer$2 = new flexunit.textui.ResultPrinter();
           else
            this.printer$2 = printer;
           this.testsComplete$2 = onComplete;
       },



   //------------------------------------------------------------------------------

       "public static function run",function run( test/*:Test*/, onComplete/*:Function=null*/, printer/*:Printer=null*/ )/*:TestResult*/
       {if(arguments.length<3){if(arguments.length<2){onComplete=null;}printer=null;}
           return new flexunit.textui.TestRunner(onComplete, printer).doRun( test );
       },

   //------------------------------------------------------------------------------

       "internal function doRun",function doRun( test/*:Test*/ )/*:TestResult*/
       {
           this.result$2 = new flexunit.framework.TestResult();
           this.result$2.addListener(/*flexunit.framework.TestListener*/( this.printer$2 ));
           this.result$2.addListener(/*flexunit.framework.TestListener*/( this ));

           this.startTime$2 = flash.utils.getTimer();
           this.totalTestCount$2 = test.countTestCases();
           this.numTestsRun$2 = 0;
           test.runWithResult( this.result$2 );
           return this.result$2;
       },

   //------------------------------------------------------------------------------

       "override public function testEnded",function testEnded( test/* : Test*/ )/*:void*/
       {
           if (++this.numTestsRun$2 == this.totalTestCount$2)
           {
               var endTime/*:Number*/ = flash.utils.getTimer();

               var runTime/*:Number*/ = endTime - this.startTime$2;

               this.printer$2.print( this.result$2, runTime );
               if(this.testsComplete$2 != null)
               {
                   this.testsComplete$2();
               }
           }
       },

       "private var",{ printer/* : Printer*/:null},
       "private var",{ startTime/* : int*/:0},
       "private var",{ totalTestCount/* : int*/:0},
       "private var",{ numTestsRun/* : int*/:0},
       "private var",{ result/*:TestResult*/:null},
       "private var",{ testsComplete/*:Function*/:null},
   ];},["run"],["flexunit.runner.BaseTestRunner","flexunit.textui.ResultPrinter","flexunit.framework.TestResult","flexunit.framework.TestListener"], "0.8.0", "0.9.5"
);

==> joounit-1.0.0.jar: joo/classes/flexunit/textui/TestRunner.js <==
joo.classLoader.prepare(/*
   Copyright (c) 2008. Adobe Systems Incorporated.
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:

     * Redistributions of source code must retain the above copyright notice,
       this list of conditions and the following disclaimer.
     * Redistributions in binary form must reproduce the above copyright notice,
       this list of conditions and the following disclaimer in the documentation
       and/or other materials provided with the distribution.
     * Neither the name of Adobe Systems Incorporated nor the names of its
       contributors may be used to endorse or promote products derived from this
       software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
*/

"package flexunit.textui",/*
{

   import flash.utils.*;
   import flash.utils.getTimer;
   import flexunit.framework.*;
   import flexunit.runner.BaseTestRunner;*/

   "public class TestRunner extends flexunit.runner.BaseTestRunner",2,function($$private){var $1=flexunit.runner,$2=flexunit.textui,$3=flexunit.framework,$4=flash.utils;return[
   
       "public function TestRunner",function TestRunner(onComplete/*:Function=null*/, printer/*:Printer=null*/)
       { $1.BaseTestRunner.call(this);switch(arguments.length){case 0:onComplete=null;case 1:printer=null;}
           if(printer == null)
            this.printer$2 = new $2.ResultPrinter();
           else
            this.printer$2 = printer;
           this.testsComplete$2 = onComplete;
       },



   //------------------------------------------------------------------------------

       "public static function run",function run( test/*:Test*/, onComplete/*:Function=null*/, printer/*:Printer=null*/ )/*:TestResult*/
       {switch(Math.max(arguments.length,1)){case 1:onComplete=null;case 2:printer=null;}
           return new $2.TestRunner(onComplete, printer).doRun( test );
       },

   //------------------------------------------------------------------------------

       "internal function doRun",function doRun( test/*:Test*/ )/*:TestResult*/
       {
           this.result$2 = new $3.TestResult();
           this.result$2.addListener(/*TestListener*/( this.printer$2 ));
           this.result$2.addListener(/*TestListener*/( this ));

           this.startTime$2 = $4.getTimer();
           this.totalTestCount$2 = test.countTestCases();
           this.numTestsRun$2 = 0;
           test.runWithResult( this.result$2 );
           return this.result$2;
       },

   //------------------------------------------------------------------------------

       "override public function testEnded",function testEnded( test/* : Test*/ )/*:void*/
       {
           if (++this.numTestsRun$2 == this.totalTestCount$2)
           {
               var endTime/*:Number*/ = $4.getTimer();

               var runTime/*:Number*/ = endTime - this.startTime$2;

               this.printer$2.print( this.result$2, runTime );
               if(this.testsComplete$2 != null)
               {
                   this.testsComplete$2();
               }
           }
       },

       "private var",{ printer/* : Printer*/:null},
       "private var",{ startTime/* : int*/:0},
       "private var",{ totalTestCount/* : int*/:0},
       "private var",{ numTestsRun/* : int*/:0},
       "private var",{ result/*:TestResult*/:null},
       "private var",{ testsComplete/*:Function*/:null},
   undefined];},["run"],["flexunit.runner.BaseTestRunner","flexunit.textui.ResultPrinter","flexunit.framework.TestResult","flexunit.framework.TestListener","flash.utils.getTimer"], "0.8.0", "1.0.0"
);
